Learn R Programming

cptec (version 0.1.1)

capitais: Current weather conditions of capitals

Description

This function allows the user to retrieve data from CPTEC/INPE current weather conditions of capitals. The data frame returned contain actual temperature, atmospheric pressure, humidity, direction and wind intensity

Usage

capitais()

Arguments

Value

The function returns a data frame

See Also

prev4dias

Examples

Run this code
# NOT RUN {
capitais()

# }

Run the code above in your browser using DataLab