Learn R Programming

cptec (version 0.1.1)

estendidaLatLon: Retrieve 14 days weather forecast data from CPTEC/INPE

Description

This function allows the user to retrieve data from CPTEC/INPE weather forecast API for the next 14 days informing latitude and longitude of the local. The data frame returned contain maximum and minimum temperature, ultra violet index and weather condition.

Usage

estendidaLatLon(lat, lon)

Arguments

lat

The latitude numeric/character vector

lon

The longitude numeric/character vector

Value

The function returns a data frame printed by the parameters input

See Also

prevEstendida

Examples

Run this code
# NOT RUN {
## Requesting weather forecast with a latitude/longitude information
prevLatLon("-20.432257", "-54.569751")

# }

Run the code above in your browser using DataLab