Learn R Programming

cptec (version 0.1.1)

listaCidades: Search for cities ID

Description

This function allows the user to discover which are the city's ID of interest.

Usage

listaCidades(x)

Arguments

x

A single character to search.

Value

The function returns a data frame with the results of the search.

See Also

prev4dias

Examples

Run this code
# NOT RUN {
## Looking for the city of Campo Grande
listaCidades("campo grande")

## Looking for the city of Rio de Janeiro
listaCidades("rio de janeiro")

# }

Run the code above in your browser using DataLab