Learn R Programming

cptec (version 0.1.1)

prevLatLon: Retrieve 7 days weather forecast data from CPTEC/INPE

Description

This function allows the user to retrieve data from CPTEC/INPE weather forecast API for the next 7 days informing latitude and longitude of the local. The data frame returned contain maximum and minimum temperature, ultra violet index and weather condition.

Usage

prevLatLon(lat, lon)

Arguments

lat

The latitude numeric/character vector

lon

The longitude numeric/character vector

Value

The function returns a data frame printed by the parameters input

Details

This function allows the user to retrieve data from CPTEC/INPE weather forecast API for the next 7 days informing latitude and longitude of the local. The data frame returned contain maximum and minimum temperature, ultra violet index and weather condition.

See Also

prev7dias

Examples

Run this code
# NOT RUN {
## Requesting weather forecast with a latitude/longitude information
prevLatLon("-20.432257", "-54.569751")
# }
# NOT RUN {

# }

Run the code above in your browser using DataLab