powered by
This function allows the user to retrieve data from CPTEC/INPE current weather conditions of capitals. The data frame returned contain actual temperature, atmospheric pressure, humidity, direction and wind intensity
capitais()
The function returns a data frame
prev4dias
# NOT RUN { capitais() # }
Run the code above in your browser using DataLab