powered by
This function allows the user to discover which are the city's ID of interest.
listaCidades(x)
A single character to search.
The function returns a data frame with the results of the search.
prev4dias
# NOT RUN { ## Looking for the city of Campo Grande listaCidades("campo grande") ## Looking for the city of Rio de Janeiro listaCidades("rio de janeiro") # }
Run the code above in your browser using DataLab