prev4dias: Retrieve 4 days weather forecast data from CPTEC/INPE
Description
This function allows the user to retrieve data from
CPTEC/INPE weather forecast API for the next 4 days.
The data frame returned contain maximum and minimum
temperature, ultra violet index and weather condition
(tempo).
Usage
prev4dias(id)
Arguments
id
The city's ID
Value
The function returns a data frame printed by city id
# NOT RUN {## Requesting weather forecast from the city of Campo Grande/MSprev4dias(225)
## Requesting weather forecast from the city of Rio de Janeiro/RJprev4dias(241)
# }